@@ -1,11 +1,12 @@
 from unittest import TestCase
 
-import tree_sitter, tree_sitter_jsdoc
+from tree_sitter import Language, Parser
+import tree_sitter_jsdoc
 
 
 class TestLanguage(TestCase):
     def test_can_load_grammar(self):
         try:
-            tree_sitter.Language(tree_sitter_jsdoc.language())
+            Parser(Language(tree_sitter_jsdoc.language()))
         except Exception:
             self.fail("Error loading JSDoc grammar")
